.. libjuju documentation master file, created by
   sphinx-quickstart on Thu May 19 11:21:38 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


.. include:: readme.rst


Table of Contents
-----------------

.. toctree::
   :glob:
   :maxdepth: 3

   narrative/index
   API Docs <api/modules>
   Internal API Docs <api/juju.client>
   upstream-updates/index


.. include:: changelog.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

